BalancesCallApi

Struct BalancesCallApi 

pub struct BalancesCallApi<'api> { /* private fields */ }

Implementations

Source

impl<'api> BalancesCallApi<'api>

pub fn transfer_allow_death( &self, dest: MultiAddress<AccountId, u32>, value: u128, ) -> Result<WrappedCall>

Transfer some liquid free balance to another account.

transfer_allow_death will set the FreeBalance of the sender and receiver. If the sender’s account is below the existential deposit as a result of the transfer, the account will be reaped.

The dispatch origin for this call must be Signed by the transactor.

pub fn force_transfer( &self, source: MultiAddress<AccountId, u32>, dest: MultiAddress<AccountId, u32>, value: u128, ) -> Result<WrappedCall>

Exactly as transfer_allow_death, except the origin must be root and the source account may be specified.

pub fn transfer_keep_alive( &self, dest: MultiAddress<AccountId, u32>, value: u128, ) -> Result<WrappedCall>

Same as the transfer_allow_death call, but with a check that the transfer will not kill the origin account.

99% of the time you want transfer_allow_death instead.

pub fn transfer_all( &self, dest: MultiAddress<AccountId, u32>, keep_alive: bool, ) -> Result<WrappedCall>

Transfer the entire transferable balance from the caller account.

NOTE: This function only attempts to transfer transferable balances. This means that any locked, reserved, or existential deposits (when keep_alive is true), will not be transferred by this function. To ensure that this function results in a killed account, you might need to prepare the account by removing any reference counters, storage deposits, etc…

The dispatch origin of this call must be Signed.

  • dest: The recipient of the transfer.
  • keep_alive: A boolean to determine if the transfer_all operation should send all of the funds the account has, causing the sender account to be killed (false), or transfer everything except at least the existential deposit, which will guarantee to keep the sender account alive (true).
pub fn force_unreserve( &self, who: MultiAddress<AccountId, u32>, amount: u128, ) -> Result<WrappedCall>

Unreserve some balance from a user by force.

Can only be called by ROOT.

pub fn upgrade_accounts(&self, who: Vec<AccountId>) -> Result<WrappedCall>

Upgrade a specified account.

  • origin: Must be Signed.
  • who: The account to be upgraded.

This will waive the transaction fee if at least all but 10% of the accounts needed to be upgraded. (We let some not have to be upgraded just in order to allow for the possibility of churn).

pub fn force_set_balance( &self, who: MultiAddress<AccountId, u32>, new_free: u128, ) -> Result<WrappedCall>

Set the regular balance of a given account.

The dispatch origin for this call is root.

pub fn force_adjust_total_issuance( &self, direction: AdjustmentDirection, delta: u128, ) -> Result<WrappedCall>

Adjust the total issuance in a saturating way.

Can only be called by root and always needs a positive delta.

Example
pub fn burn(&self, value: u128, keep_alive: bool) -> Result<WrappedCall>

Burn the specified liquid free balance from the origin account.

If the origin’s account ends up below the existential deposit as a result of the burn and keep_alive is false, the account will be reaped.

Unlike sending funds to a burn address, which merely makes the funds inaccessible, this burn operation will reduce total issuance by the amount burned.

pub fn transfer_with_memo( &self, dest: MultiAddress<AccountId, u32>, value: u128, memo: Option<Memo>, ) -> Result<WrappedCall>

Transfer some liquid free balance to another account.

transfer will set the FreeBalance of the sender and receiver. If the sender’s account is below the existential deposit as a result of the transfer, the account will be reaped.

The dispatch origin for this call must be Signed by the transactor.

Complexity
  • Dependent on arguments but not critical, given proper implementations for input config types. See related functions below.
  • It contains a limited number of reads and writes internally and no complex computation.

Related functions:

  • ensure_can_withdraw is always called internally but has a bounded complexity.
  • Transferring balances to accounts that did not exist before will cause T::OnNewAccount::on_new_account to be called.
  • Removing enough funds from an account will trigger T::DustRemoval::on_unbalanced.
  • transfer_keep_alive works the same way as transfer, but has an additional check that the transfer will not kill the origin account.