pub struct BalancesQueryApi<'api> { /* private fields */ }Implementations
Sourceimpl<'api> BalancesQueryApi<'api>
impl<'api> BalancesQueryApi<'api>
Sourcepub async fn total_issuance(&self) -> Result<u128>
pub async fn total_issuance(&self) -> Result<u128>
The total units issued in the system.
Sourcepub async fn inactive_issuance(&self) -> Result<u128>
pub async fn inactive_issuance(&self) -> Result<u128>
The total units of outstanding deactivated balance in the system.
Sourcepub async fn account(&self, key_0: AccountId) -> Result<AccountData<u128>>
pub async fn account(&self, key_0: AccountId) -> Result<AccountData<u128>>
The Balances pallet example of storing the balance of an account.
Example
impl pallet_balances::Config for Runtime {
type AccountStore = StorageMapShim<Self::Account<Runtime>, frame_system::Provider<Runtime>, AccountId, Self::AccountData<Balance>>
}You can also store the balance of an account in the System pallet.
Example
impl pallet_balances::Config for Runtime {
type AccountStore = System
}But this comes with tradeoffs, storing account balances in the system pallet stores
frame_system data alongside the account data contrary to storing account balances in the
Balances pallet, which uses a StorageMap to store balances data only.
NOTE: This is only used in the case that this pallet is used to store balances.
Sourcepub async fn locks(&self, key_0: AccountId) -> Result<Vec<BalanceLock<u128>>>
pub async fn locks(&self, key_0: AccountId) -> Result<Vec<BalanceLock<u128>>>
Any liquidity locks on some account balances. NOTE: Should only be accessed when setting, changing and freeing a lock.
Use of locks is deprecated in favour of freezes. See https://github.com/paritytech/substrate/pull/12951/
Sourcepub async fn reserves(
&self,
key_0: AccountId,
) -> Result<Vec<ReserveData<[u8; 8], u128>>>
pub async fn reserves( &self, key_0: AccountId, ) -> Result<Vec<ReserveData<[u8; 8], u128>>>
Named reserves on some account balances.
Use of reserves is deprecated in favour of holds. See https://github.com/paritytech/substrate/pull/12951/