pub struct BeefyCallApi<'api> { /* private fields */ }Implementations
Sourceimpl<'api> BeefyCallApi<'api>
impl<'api> BeefyCallApi<'api>
Sourcepub fn report_double_voting(
&self,
equivocation_proof: DoubleVotingProof<u32, Public, Signature>,
key_owner_proof: MembershipProof,
) -> Result<WrappedCall>
pub fn report_double_voting( &self, equivocation_proof: DoubleVotingProof<u32, Public, Signature>, key_owner_proof: MembershipProof, ) -> Result<WrappedCall>
Report voter equivocation/misbehavior. This method will verify the equivocation proof and validate the given key ownership proof against the extracted offender. If both are valid, the offence will be reported.
Sourcepub fn report_double_voting_unsigned(
&self,
equivocation_proof: DoubleVotingProof<u32, Public, Signature>,
key_owner_proof: MembershipProof,
) -> Result<WrappedCall>
pub fn report_double_voting_unsigned( &self, equivocation_proof: DoubleVotingProof<u32, Public, Signature>, key_owner_proof: MembershipProof, ) -> Result<WrappedCall>
Report voter equivocation/misbehavior. This method will verify the equivocation proof and validate the given key ownership proof against the extracted offender. If both are valid, the offence will be reported.
This extrinsic must be called unsigned and it is expected that only
block authors will call it (validated in ValidateUnsigned), as such
if the block author is defined it will be defined as the equivocation
reporter.
Sourcepub fn set_new_genesis(&self, delay_in_blocks: u32) -> Result<WrappedCall>
pub fn set_new_genesis(&self, delay_in_blocks: u32) -> Result<WrappedCall>
Reset BEEFY consensus by setting a new BEEFY genesis at delay_in_blocks blocks in the
future.
Note: delay_in_blocks has to be at least 1.
Sourcepub fn report_fork_voting(
&self,
equivocation_proof: ForkVotingProof<Header<u32>, Public, AncestryProof<H256>>,
key_owner_proof: MembershipProof,
) -> Result<WrappedCall>
pub fn report_fork_voting( &self, equivocation_proof: ForkVotingProof<Header<u32>, Public, AncestryProof<H256>>, key_owner_proof: MembershipProof, ) -> Result<WrappedCall>
Report fork voting equivocation. This method will verify the equivocation proof and validate the given key ownership proof against the extracted offender. If both are valid, the offence will be reported.
Sourcepub fn report_fork_voting_unsigned(
&self,
equivocation_proof: ForkVotingProof<Header<u32>, Public, AncestryProof<H256>>,
key_owner_proof: MembershipProof,
) -> Result<WrappedCall>
pub fn report_fork_voting_unsigned( &self, equivocation_proof: ForkVotingProof<Header<u32>, Public, AncestryProof<H256>>, key_owner_proof: MembershipProof, ) -> Result<WrappedCall>
Report fork voting equivocation. This method will verify the equivocation proof and validate the given key ownership proof against the extracted offender. If both are valid, the offence will be reported.
This extrinsic must be called unsigned and it is expected that only
block authors will call it (validated in ValidateUnsigned), as such
if the block author is defined it will be defined as the equivocation
reporter.
Sourcepub fn report_future_block_voting(
&self,
equivocation_proof: FutureBlockVotingProof<u32, Public>,
key_owner_proof: MembershipProof,
) -> Result<WrappedCall>
pub fn report_future_block_voting( &self, equivocation_proof: FutureBlockVotingProof<u32, Public>, key_owner_proof: MembershipProof, ) -> Result<WrappedCall>
Report future block voting equivocation. This method will verify the equivocation proof and validate the given key ownership proof against the extracted offender. If both are valid, the offence will be reported.
Sourcepub fn report_future_block_voting_unsigned(
&self,
equivocation_proof: FutureBlockVotingProof<u32, Public>,
key_owner_proof: MembershipProof,
) -> Result<WrappedCall>
pub fn report_future_block_voting_unsigned( &self, equivocation_proof: FutureBlockVotingProof<u32, Public>, key_owner_proof: MembershipProof, ) -> Result<WrappedCall>
Report future block voting equivocation. This method will verify the equivocation proof and validate the given key ownership proof against the extracted offender. If both are valid, the offence will be reported.
This extrinsic must be called unsigned and it is expected that only
block authors will call it (validated in ValidateUnsigned), as such
if the block author is defined it will be defined as the equivocation
reporter.