pub struct BeefyPagedQueryApi<'api> { /* private fields */ }Implementations
Sourceimpl<'api> BeefyPagedQueryApi<'api>
impl<'api> BeefyPagedQueryApi<'api>
Sourcepub fn set_id_session(&self) -> StoragePaged<u64, u32>
pub fn set_id_session(&self) -> StoragePaged<u64, u32>
A mapping from BEEFY set ID to the index of the most recent session for which its members were responsible.
This is only used for validating equivocation proofs. An equivocation proof must contains a key-ownership proof for a given session, therefore we need a way to tie together sessions and BEEFY set ids, i.e. we need to validate that a validator was the owner of a given key on a given session, and what the active set ID was during that session.
TWOX-NOTE: ValidatorSetId is not under user control.