pub struct BeefyQueryApi<'api> { /* private fields */ }Implementations
Sourceimpl<'api> BeefyQueryApi<'api>
impl<'api> BeefyQueryApi<'api>
The current authorities set
Sourcepub async fn validator_set_id(&self) -> Result<u64>
pub async fn validator_set_id(&self) -> Result<u64>
The current validator set id
Authorities set scheduled to be used with the next session
Sourcepub async fn set_id_session(&self, key_0: u64) -> Result<Option<u32>>
pub async fn set_id_session(&self, key_0: u64) -> Result<Option<u32>>
A mapping from BEEFY set ID to the index of the most recent session for which its members were responsible.
This is only used for validating equivocation proofs. An equivocation proof must contains a key-ownership proof for a given session, therefore we need a way to tie together sessions and BEEFY set ids, i.e. we need to validate that a validator was the owner of a given key on a given session, and what the active set ID was during that session.
TWOX-NOTE: ValidatorSetId is not under user control.
Sourcepub async fn genesis_block(&self) -> Result<Option<u32>>
pub async fn genesis_block(&self) -> Result<Option<u32>>
Block number where BEEFY consensus is enabled/started.
By changing this (through privileged set_new_genesis()), BEEFY consensus is effectively
restarted from the newly set block number.