ConfidentialAssetsCallApi

Struct ConfidentialAssetsCallApi 

pub struct ConfidentialAssetsCallApi<'api> { /* private fields */ }

Implementations

Source

impl<'api> ConfidentialAssetsCallApi<'api>

pub fn register_accounts( &self, proof: AccountRegistrationProof, ) -> Result<WrappedCall>

Register a dart account.

Arguments
  • account the dart account to register.
  • encryption_key the encryption key for the dart account.
Errors
  • BadOrigin if origin isn’t signed.
  • AccountAlreadyCreated if the dart account or encryption key is already registered.
pub fn register_encryption_keys( &self, proof: EncryptionKeyRegistrationProof, ) -> Result<WrappedCall>

Register encryption keys for auditors/mediators.

Arguments
  • origin - The origin of the call.
  • proof - The auditor/mediator encryption registration proof.
Errors
  • BadOrigin if origin isn’t signed.
  • EncryptionKeyAlreadyRegistered if the encryption key is already registered.
  • InvalidProof if the proof is invalid.
pub fn create_asset( &self, name: Name, symbol: Symbol, decimals: u8, mediators: BTreeMap<AccountPublicKey, EncryptionPublicKey>, auditors: BTreeSet<EncryptionPublicKey>, data: Vec<u8>, ) -> Result<WrappedCall>

Create a new Confidential Asset.

Arguments
  • auditor_or_mediator - The auditor or mediator public key.
Errors
  • BadOrigin if origin isn’t signed.
  • AccountMissing if the auditor or mediator is not registered.
  • EncryptionKeyMissing if the encryption key of the auditor or mediator is not registered.
pub fn register_account_assets( &self, proof: BatchedAccountAssetRegistrationProof, ) -> Result<WrappedCall>

Batch register multiple accounts and assets.

This is used to initialize the first account state commitment of the Confidential asset for the Confidential account.

Arguments
  • origin - The origin of the call. They must be the owner of the Confidential account.
  • proof - The Batched Account asset registration proof.
Errors
  • BadOrigin if origin isn’t signed.
  • AccountMissing if the Confidential account is not registered.
  • AssetMissing if the Confidential asset is not registered.
  • AccountAssetAlreadyRegistered if the Confidential account has already registered the Confidential asset.
  • NotAccountOwner if the caller is not the owner of the Confidential account.
  • InvalidProof if the proof is invalid.
pub fn mint_asset(&self, proof: AssetMintingProof) -> Result<WrappedCall>

Mint a Confidential asset.

Arguments
  • origin - The origin of the call. They must be the owner of the Confidential asset and Confidential account.
  • proof - The minting proof.
Errors
  • BadOrigin if origin isn’t signed.
  • AccountMissing if the Confidential account is not registered.
  • AssetMissing if the Confidential asset is not registered.
  • NotAccountOwner if the caller is not the owner of the Confidential account.
  • InvalidProof if the proof is invalid.
  • NotAssetOwner if the caller is not the owner of the Confidential asset.
  • MaxTotalSupplyExceeded if the total supply of the Confidential asset exceeds the maximum total supply.
  • NullifierAlreadyUsed if the nullifier for the account state commitment has already been used.
pub fn create_settlement(&self, proof: SettlementProof) -> Result<WrappedCall>

Create a new settlement.

Arguments
  • origin - The origin of the call.
  • proof - The settlement proof.
Errors
  • BadOrigin if origin isn’t signed.
  • InvalidProof if the proof is invalid.
  • SettlementMissingLegs if the settlement has no legs.
  • SettlementTooManyLegs if the settlement has more legs than the maximum allowed.
pub fn sender_affirmation( &self, proof: SenderAffirmationProof, ) -> Result<WrappedCall>

Sender affirms a settlement leg.

Arguments
  • origin - The origin of the call.
  • proof - The sender affirmation proof.
Errors
  • BadOrigin if origin isn’t signed.
  • SettlementNotPending if the settlement is not pending.
  • SettlementNotFound if the settlement is not found.
  • LegNotFound if the leg is not found in the settlement.
  • AlreadyAffirmed if the leg has already been affirmed by the sender.
pub fn receiver_affirmation( &self, proof: ReceiverAffirmationProof, ) -> Result<WrappedCall>

Receiver affirms a settlement leg.

Arguments
  • origin - The origin of the call.
  • proof - The receiver affirmation proof.
Errors
  • BadOrigin if origin isn’t signed.
  • SettlementNotPending if the settlement is not pending.
  • SettlementNotFound if the settlement is not found.
  • LegNotFound if the leg is not found in the settlement.
  • AlreadyAffirmed if the leg has already been affirmed by the receiver.
pub fn mediator_affirmation( &self, proof: MediatorAffirmationProof, ) -> Result<WrappedCall>

Mediator affirms a settlement leg.

Arguments
  • origin - The origin of the call.
  • proof - The mediator affirmation proof.
Errors
  • BadOrigin if origin isn’t signed.
  • SettlementNotPending if the settlement is not pending.
  • SettlementNotFound if the settlement is not found.
  • LegNotFound if the leg is not found in the settlement.
  • AlreadyAffirmed if the leg has already been affirmed by the mediator.
  • WrongMediatorId if the mediator ID does not match the expected mediator for the leg.
pub fn sender_update_counter( &self, proof: SenderCounterUpdateProof, ) -> Result<WrappedCall>

Sender updates their counter after a settlement has been executed.

Arguments
  • origin - The origin of the call.
  • proof - The sender update proof.
Errors
  • BadOrigin if origin isn’t signed.
  • SettlementNotExecuted if the settlement has not been executed.
  • SettlementNotFound if the settlement is not found.
  • LegNotFound if the leg is not found in the settlement.
pub fn sender_revert_affirmation( &self, proof: SenderRevertAffirmationProof, ) -> Result<WrappedCall>

Sender reverts their affirmation.

Arguments
  • origin - The origin of the call.
  • proof - The sender revert affirmation proof.
Errors
  • BadOrigin if origin isn’t signed.
  • SettlementAlreadyExecuted if the settlement has already been executed.
  • SettlementNotFound if the settlement is not found.
  • LegNotFound if the leg is not found in the settlement.
pub fn receiver_revert_affirmation( &self, proof: ReceiverRevertAffirmationProof, ) -> Result<WrappedCall>

Receiver reverts their affirmation.

Arguments
  • origin - The origin of the call.
  • proof - The receiver revert affirmation proof.
Errors
  • BadOrigin if origin isn’t signed.
  • SettlementAlreadyExecuted if the settlement has already been executed.
  • SettlementNotFound if the settlement is not found.
  • LegNotFound if the leg is not found in the settlement.
pub fn receiver_claim(&self, proof: ReceiverClaimProof) -> Result<WrappedCall>

Receiver claims their assets after a settlement has been executed.

Arguments
  • origin - The origin of the call.
  • proof - The receiver claim proof.
Errors
  • BadOrigin if origin isn’t signed.
  • SettlementNotExecuted if the settlement has not been executed.
  • SettlementNotFound if the settlement is not found.
  • LegNotFound if the leg is not found in the settlement.
pub fn batched_settlement( &self, proof: BatchedSettlementProof<AssetTreeConfig, AccountTreeConfig>, ) -> Result<WrappedCall>

Create a settlement with batched leg affirmations.

Arguments
  • origin - The origin of the call.
  • proof - The settlement proof with batched leg affirmations.
Errors
  • BadOrigin if origin isn’t signed.
  • InvalidProof if the proof is invalid.
  • SettlementMissingLegs if the settlement has no legs.
  • SettlementTooManyLegs if the settlement has more legs than the maximum allowed.
pub fn register_fee_accounts( &self, proof: BatchedFeeAccountRegistrationProof, ) -> Result<WrappedCall>

Batch register multiple fee accounts.

This is used to register fee accounts for Confidential private fee payments.

Arguments
  • origin - The origin of the call.
  • proof - The batched fee account registration proof.
Errors
  • BadOrigin if origin isn’t signed.
  • FeeAccountAlreadyRegistered if the fee account or encryption key is already registered.
  • NullifierAlreadyUsed if the nullifier for the fee account state commitment has already been used.
  • InvalidFeeAssetId if the fee asset ID is invalid.
  • InvalidProof if the proof is invalid.
  • InsufficientBalance if the caller has insufficient balance to pay the deposit.
pub fn topup_fee_accounts( &self, proof: BatchedFeeAccountTopupProof, ) -> Result<WrappedCall>

Toup a batch of fee accounts.

Arguments
  • origin - The origin of the call.
  • proof - The batched fee account topup proof.
Errors
  • BadOrigin if origin isn’t signed.
  • FeeAccountMissing if the fee account is not registered.
  • InvalidFeeAssetId if the fee asset ID is invalid.
  • InvalidProof if the proof is invalid.
  • InsufficientBalance if the caller has insufficient balance to pay the deposit.
pub fn submit_batched_proofs(&self, proof: BatchedProofs) -> Result<WrappedCall>

Submit a batch of proofs.

Arguments
  • origin - The origin of the call.
  • proof - The batched proofs.
Errors
  • BadOrigin if origin isn’t signed.
  • InvalidProof if any of the proofs are invalid.
pub fn relayer_submit_batched_proofs( &self, proof: FeePaymentWithBatchedProofs, ) -> Result<WrappedCall>

Relayer submit a batch of proofs paid using a private fee payment.

Users can use a Relayer service to submit their Confidential proofs for privacy (i.e., the origin is not the user). The Relayer is paid/reimbursed using a private fee payment from the user’s Confidential fee account.

Relayers can charge a commission fee on top of the transaction fee (i.e. commission fee + transaction fee = fee amount).

Relayers should verify that the fee payment proof is valid before submitting the batched Confidential proofs. They are not required to verify the batched Confidential proofs. If the user’s Confidential proofs are invalid, the user is still responsible for paying the fee to the relayer.

Arguments
  • origin - The origin of the call. This is the relayer.
  • proof - The fee payment proof and batched Confidential proofs.
Errors
  • BadOrigin if origin isn’t signed.
  • InvalidFeePaymentProof if the fee payment proof is invalid.
  • InsufficientFeePayment if the fee payment is insufficient to cover the relayer fee.
pub fn execute_instant_settlement( &self, proof: InstantSettlementProof<AssetTreeConfig, AccountTreeConfig>, ) -> Result<WrappedCall>

Create and execute an instant settlement.

Arguments
  • origin - The origin of the call.
  • proof - The settlement proof with batched leg affirmations.
Errors
  • BadOrigin if origin isn’t signed.
  • InvalidProof if the proof is invalid.
  • SettlementMissingLegs if the settlement has no legs.
  • SettlementTooManyLegs if the settlement has more legs than the maximum allowed.
pub fn instant_sender_affirmation( &self, proof: InstantSenderAffirmationProof, ) -> Result<WrappedCall>

Sender affirms a settlement leg as the last pending affirmation.

This can only be used when the sender affirmation is the last pending affirmation for the settlement.

Arguments
  • origin - The origin of the call.
  • proof - The instant sender affirmation proof.
Errors
  • BadOrigin if origin isn’t signed.
  • SettlementNotPending if the settlement is not pending.
  • SettlementNotFound if the settlement is not found.
  • LegNotFound if the leg is not found in the settlement.
  • AlreadyAffirmed if the leg has already been affirmed by the sender.
  • NotLastPendingAffirmation if the sender affirmation is not the last pending affirmation for the settlement.
pub fn instant_receiver_affirmation( &self, proof: InstantReceiverAffirmationProof, ) -> Result<WrappedCall>

Receiver affirms a settlement leg as the last pending affirmation.

This can only be used when the receiver affirmation is the last pending affirmation for the settlement.

Arguments
  • origin - The origin of the call.
  • proof - The instant receiver affirmation proof.
Errors
  • BadOrigin if origin isn’t signed.
  • SettlementNotPending if the settlement is not pending.
  • SettlementNotFound if the settlement is not found.
  • LegNotFound if the leg is not found in the settlement.
  • AlreadyAffirmed if the leg has already been affirmed by the receiver.
  • NotLastPendingAffirmation if the receiver affirmation is not the last pending affirmation for the settlement.