pub struct ConfidentialAssetsPagedQueryApi<'api> { /* private fields */ }Implementations
Sourceimpl<'api> ConfidentialAssetsPagedQueryApi<'api>
impl<'api> ConfidentialAssetsPagedQueryApi<'api>
Sourcepub fn details(&self) -> StoragePaged<u32, AssetDetails>
pub fn details(&self) -> StoragePaged<u32, AssetDetails>
Mapping of Confidential Asset ID to its details.
Sourcepub fn keys(&self) -> StoragePaged<u32, AssetKeys>
pub fn keys(&self) -> StoragePaged<u32, AssetKeys>
Mapping of Confidential Asset ID to its auditor and mediator keys.
Sourcepub fn names(&self) -> StoragePaged<u32, Name>
pub fn names(&self) -> StoragePaged<u32, Name>
A Confidential assets token name.
Sourcepub fn symbols(&self) -> StoragePaged<u32, Symbol>
pub fn symbols(&self) -> StoragePaged<u32, Symbol>
A Confidential assets token symbol.
Sourcepub fn decimals(&self) -> StoragePaged<u32, u8>
pub fn decimals(&self) -> StoragePaged<u32, u8>
A Confidential assets token decimals.
Sourcepub fn owner_assets(&self, key_0: IdentityId) -> StoragePaged<u32, ()>
pub fn owner_assets(&self, key_0: IdentityId) -> StoragePaged<u32, ()>
Mapping of asset owner to their assets.
Sourcepub fn encryption_key_did(
&self,
) -> StoragePaged<EncryptionPublicKey, IdentityId>
pub fn encryption_key_did( &self, ) -> StoragePaged<EncryptionPublicKey, IdentityId>
Encryption key to identity mapping.
This is used for the auditor and mediator encryption keys.
Sourcepub fn account_did(&self) -> StoragePaged<AccountPublicKey, IdentityId>
pub fn account_did(&self) -> StoragePaged<AccountPublicKey, IdentityId>
Confidential account to identity mapping.
Sourcepub fn did_accounts(
&self,
key_0: IdentityId,
) -> StoragePaged<AccountPublicKey, ()>
pub fn did_accounts( &self, key_0: IdentityId, ) -> StoragePaged<AccountPublicKey, ()>
Mapping of identity to their Confidential accounts.
Sourcepub fn fee_account_did(&self) -> StoragePaged<AccountPublicKey, IdentityId>
pub fn fee_account_did(&self) -> StoragePaged<AccountPublicKey, IdentityId>
Confidential fee account to identity mapping.
Sourcepub fn account_encryption_key(
&self,
) -> StoragePaged<AccountPublicKey, EncryptionPublicKey>
pub fn account_encryption_key( &self, ) -> StoragePaged<AccountPublicKey, EncryptionPublicKey>
Mapping of Confidential account public keys to their encryption keys.
Sourcepub fn encryption_key_account(
&self,
) -> StoragePaged<EncryptionPublicKey, AccountPublicKey>
pub fn encryption_key_account( &self, ) -> StoragePaged<EncryptionPublicKey, AccountPublicKey>
Mapping of Confidential encryption keys to their public keys.
Sourcepub fn account_asset_registrations(
&self,
key_0: AccountPublicKey,
) -> StoragePaged<u32, bool>
pub fn account_asset_registrations( &self, key_0: AccountPublicKey, ) -> StoragePaged<u32, bool>
Confidential account asset registrations.
The chain must prevent the same account from registering the same asset multiple times.
This is a double map where the first key is the account public key and the second key is the asset ID.
Sourcepub fn asset_leaves(&self) -> StoragePaged<u64, CompressedLeafValue>
pub fn asset_leaves(&self) -> StoragePaged<u64, CompressedLeafValue>
Leaf storage for Confidential assets curve tree.
A counted map is used since we need to support updating the leaves in the tree.
Sourcepub fn asset_inner_nodes(&self) -> StoragePaged<NodeLocation, CompressedInner>
pub fn asset_inner_nodes(&self) -> StoragePaged<NodeLocation, CompressedInner>
Inner node storage for Confidential assets curve tree.
Sourcepub fn asset_curve_tree_roots(
&self,
) -> StoragePaged<u32, TimestampedTreeRoot<CompressedCurveTreeRoot>>
pub fn asset_curve_tree_roots( &self, ) -> StoragePaged<u32, TimestampedTreeRoot<CompressedCurveTreeRoot>>
CurveTree Roots for Confidential assets curve tree.
At the end of each block we will store the root of the assets curve tree. The map key is the block number and the value is the root of the assets curve tree.
Sourcepub fn account_leaves(&self) -> StoragePaged<u64, AccountStateCommitment>
pub fn account_leaves(&self) -> StoragePaged<u64, AccountStateCommitment>
Leaf storage for Confidential accounts curve tree.
The leaves are immutable, so we use a simple storage map.
Sourcepub fn account_inner_nodes(&self) -> StoragePaged<NodeLocation, CompressedInner>
pub fn account_inner_nodes(&self) -> StoragePaged<NodeLocation, CompressedInner>
Inner node storage for Confidential accounts curve tree.
Sourcepub fn account_curve_tree_roots(
&self,
) -> StoragePaged<u32, TimestampedTreeRoot<CompressedCurveTreeRoot>>
pub fn account_curve_tree_roots( &self, ) -> StoragePaged<u32, TimestampedTreeRoot<CompressedCurveTreeRoot>>
CurveTree Roots for Confidential accounts curve tree.
At the end of each block we will store the root of the accounts curve tree. The map key is the block number and the value is the root of the accounts curve tree.
Sourcepub fn account_state_commitment_nullifiers(
&self,
) -> StoragePaged<AccountStateNullifier, ()>
pub fn account_state_commitment_nullifiers( &self, ) -> StoragePaged<AccountStateNullifier, ()>
Nullifiers for Confidential account state commitments.
This is used to ensure that the same account state commitment cannot be used twice.
Sourcepub fn fee_account_registrations(&self) -> StoragePaged<AccountPublicKey, bool>
pub fn fee_account_registrations(&self) -> StoragePaged<AccountPublicKey, bool>
Confidential fee account egistrations.
The chain must prevent the same account from registering the multiple times.
Sourcepub fn fee_account_leaves(&self) -> StoragePaged<u64, FeeAccountStateCommitment>
pub fn fee_account_leaves(&self) -> StoragePaged<u64, FeeAccountStateCommitment>
Leaf storage for Confidential fee accounts curve tree.
The leaves are immutable, so we use a simple storage map.
Sourcepub fn fee_account_inner_nodes(
&self,
) -> StoragePaged<NodeLocation, CompressedInner>
pub fn fee_account_inner_nodes( &self, ) -> StoragePaged<NodeLocation, CompressedInner>
Inner node storage for Confidential fee accounts curve tree.
Sourcepub fn fee_account_curve_tree_roots(
&self,
) -> StoragePaged<u32, TimestampedTreeRoot<CompressedCurveTreeRoot>>
pub fn fee_account_curve_tree_roots( &self, ) -> StoragePaged<u32, TimestampedTreeRoot<CompressedCurveTreeRoot>>
CurveTree Roots for Confidential fee accounts curve tree.
At the end of each block we will store the root of the fee accounts curve tree. The map key is the block number and the value is the root of the fee accounts curve tree.
Sourcepub fn fee_account_state_commitment_nullifiers(
&self,
) -> StoragePaged<FeeAccountStateNullifier, ()>
pub fn fee_account_state_commitment_nullifiers( &self, ) -> StoragePaged<FeeAccountStateNullifier, ()>
Nullifiers for Confidential fee account state commitments.
This is used to ensure that the same fee account state commitment cannot be used twice.
Sourcepub fn settlement_state(&self) -> StoragePaged<SettlementRef, SettlementStatus>
pub fn settlement_state(&self) -> StoragePaged<SettlementRef, SettlementStatus>
The settlement status.
Sourcepub fn settlement_memo(&self) -> StoragePaged<SettlementRef, Vec<u8>>
pub fn settlement_memo(&self) -> StoragePaged<SettlementRef, Vec<u8>>
The settlement memo.
Sourcepub fn settlement_legs(
&self,
key_0: SettlementRef,
) -> StoragePaged<u8, LegEncrypted>
pub fn settlement_legs( &self, key_0: SettlementRef, ) -> StoragePaged<u8, LegEncrypted>
The settlement legs.
This is a double map where the first key is the settlement ID and the second key is the leg ID. The value is the DartSettlementLeg.
Sourcepub fn settlement_leg_count(&self) -> StoragePaged<SettlementRef, u32>
pub fn settlement_leg_count(&self) -> StoragePaged<SettlementRef, u32>
The number of legs in each settlement.
Sourcepub fn settlement_pending_affirmations(
&self,
) -> StoragePaged<SettlementRef, u32>
pub fn settlement_pending_affirmations( &self, ) -> StoragePaged<SettlementRef, u32>
The number of pending affirmations for a settlement. This is used to track when a settlement can be executed.
Sourcepub fn settlement_pending_finalizations(
&self,
) -> StoragePaged<SettlementRef, u32>
pub fn settlement_pending_finalizations( &self, ) -> StoragePaged<SettlementRef, u32>
The number of pending finalizations for a settlement. This is used to track when a settlement can be finalized and all storage can be cleaned up.
Sourcepub fn leg_affirmation_status(
&self,
key_0: SettlementRef,
key_1: u8,
) -> StoragePaged<LegAffirmParty, AffirmationStatus>
pub fn leg_affirmation_status( &self, key_0: SettlementRef, key_1: u8, ) -> StoragePaged<LegAffirmParty, AffirmationStatus>
The affirmation status of each party in a settlement leg. This is a triple map where the first key is the settlement ID, the second key is the leg ID, and the third key is the party (sender, receiver, mediator).