pub struct ConfidentialAssetsQueryApi<'api> { /* private fields */ }Implementations
Sourceimpl<'api> ConfidentialAssetsQueryApi<'api>
impl<'api> ConfidentialAssetsQueryApi<'api>
Sourcepub async fn next_asset_id(&self) -> Result<u32>
pub async fn next_asset_id(&self) -> Result<u32>
Next Asset ID to be used for Confidential assets.
Sourcepub async fn details(&self, key_0: u32) -> Result<Option<AssetDetails>>
pub async fn details(&self, key_0: u32) -> Result<Option<AssetDetails>>
Mapping of Confidential Asset ID to its details.
Sourcepub async fn keys(&self, key_0: u32) -> Result<Option<AssetKeys>>
pub async fn keys(&self, key_0: u32) -> Result<Option<AssetKeys>>
Mapping of Confidential Asset ID to its auditor and mediator keys.
Sourcepub async fn names(&self, key_0: u32) -> Result<Option<Name>>
pub async fn names(&self, key_0: u32) -> Result<Option<Name>>
A Confidential assets token name.
Sourcepub async fn symbols(&self, key_0: u32) -> Result<Option<Symbol>>
pub async fn symbols(&self, key_0: u32) -> Result<Option<Symbol>>
A Confidential assets token symbol.
Sourcepub async fn decimals(&self, key_0: u32) -> Result<Option<u8>>
pub async fn decimals(&self, key_0: u32) -> Result<Option<u8>>
A Confidential assets token decimals.
Sourcepub async fn owner_assets(
&self,
key_0: IdentityId,
key_1: u32,
) -> Result<Option<()>>
pub async fn owner_assets( &self, key_0: IdentityId, key_1: u32, ) -> Result<Option<()>>
Mapping of asset owner to their assets.
Sourcepub async fn encryption_key_did(
&self,
key_0: EncryptionPublicKey,
) -> Result<Option<IdentityId>>
pub async fn encryption_key_did( &self, key_0: EncryptionPublicKey, ) -> Result<Option<IdentityId>>
Encryption key to identity mapping.
This is used for the auditor and mediator encryption keys.
Sourcepub async fn account_did(
&self,
key_0: AccountPublicKey,
) -> Result<Option<IdentityId>>
pub async fn account_did( &self, key_0: AccountPublicKey, ) -> Result<Option<IdentityId>>
Confidential account to identity mapping.
Sourcepub async fn did_accounts(
&self,
key_0: IdentityId,
key_1: AccountPublicKey,
) -> Result<Option<()>>
pub async fn did_accounts( &self, key_0: IdentityId, key_1: AccountPublicKey, ) -> Result<Option<()>>
Mapping of identity to their Confidential accounts.
Sourcepub async fn fee_account_did(
&self,
key_0: AccountPublicKey,
) -> Result<Option<IdentityId>>
pub async fn fee_account_did( &self, key_0: AccountPublicKey, ) -> Result<Option<IdentityId>>
Confidential fee account to identity mapping.
Sourcepub async fn account_encryption_key(
&self,
key_0: AccountPublicKey,
) -> Result<Option<EncryptionPublicKey>>
pub async fn account_encryption_key( &self, key_0: AccountPublicKey, ) -> Result<Option<EncryptionPublicKey>>
Mapping of Confidential account public keys to their encryption keys.
Sourcepub async fn encryption_key_account(
&self,
key_0: EncryptionPublicKey,
) -> Result<Option<AccountPublicKey>>
pub async fn encryption_key_account( &self, key_0: EncryptionPublicKey, ) -> Result<Option<AccountPublicKey>>
Mapping of Confidential encryption keys to their public keys.
Sourcepub async fn account_asset_registrations(
&self,
key_0: AccountPublicKey,
key_1: u32,
) -> Result<bool>
pub async fn account_asset_registrations( &self, key_0: AccountPublicKey, key_1: u32, ) -> Result<bool>
Confidential account asset registrations.
The chain must prevent the same account from registering the same asset multiple times.
This is a double map where the first key is the account public key and the second key is the asset ID.
Sourcepub async fn asset_leaves(
&self,
key_0: u64,
) -> Result<Option<CompressedLeafValue>>
pub async fn asset_leaves( &self, key_0: u64, ) -> Result<Option<CompressedLeafValue>>
Leaf storage for Confidential assets curve tree.
A counted map is used since we need to support updating the leaves in the tree.
Sourcepub async fn counter_for_asset_leaves(&self) -> Result<u32>
pub async fn counter_for_asset_leaves(&self) -> Result<u32>
Counter for the related counted storage map
Sourcepub async fn asset_inner_nodes(
&self,
key_0: NodeLocation,
) -> Result<Option<CompressedInner>>
pub async fn asset_inner_nodes( &self, key_0: NodeLocation, ) -> Result<Option<CompressedInner>>
Inner node storage for Confidential assets curve tree.
Sourcepub async fn asset_curve_tree_current_root(
&self,
) -> Result<Option<TimestampedTreeRoot<CompressedCurveTreeRoot>>>
pub async fn asset_curve_tree_current_root( &self, ) -> Result<Option<TimestampedTreeRoot<CompressedCurveTreeRoot>>>
The current CurveTree Root for Confidential assets curve tree.
Sourcepub async fn asset_curve_tree_height(&self) -> Result<u8>
pub async fn asset_curve_tree_height(&self) -> Result<u8>
The height of the assets curve tree.
Sourcepub async fn asset_curve_tree_roots(
&self,
key_0: u32,
) -> Result<Option<TimestampedTreeRoot<CompressedCurveTreeRoot>>>
pub async fn asset_curve_tree_roots( &self, key_0: u32, ) -> Result<Option<TimestampedTreeRoot<CompressedCurveTreeRoot>>>
CurveTree Roots for Confidential assets curve tree.
At the end of each block we will store the root of the assets curve tree. The map key is the block number and the value is the root of the assets curve tree.
Sourcepub async fn asset_curve_tree_last_update(&self) -> Result<CurveTreeTimestamp>
pub async fn asset_curve_tree_last_update(&self) -> Result<CurveTreeTimestamp>
The block number of the last asset curve tree root update.
This is used to track the last time the asset curve tree was updated.
Sourcepub async fn asset_curve_tree_last_pruned(&self) -> Result<u32>
pub async fn asset_curve_tree_last_pruned(&self) -> Result<u32>
The block number of the last asset curve tree root pruned.
For keeping track of the current pruning point of the asset curve tree roots.
Sourcepub async fn account_leaves(
&self,
key_0: u64,
) -> Result<Option<AccountStateCommitment>>
pub async fn account_leaves( &self, key_0: u64, ) -> Result<Option<AccountStateCommitment>>
Leaf storage for Confidential accounts curve tree.
The leaves are immutable, so we use a simple storage map.
Sourcepub async fn next_account_leaf_index(&self) -> Result<u64>
pub async fn next_account_leaf_index(&self) -> Result<u64>
Next leaf index for Confidential accounts curve tree.
This is used to allocate new leaves in the tree.
Sourcepub async fn last_committed_account_leaf_index(&self) -> Result<u64>
pub async fn last_committed_account_leaf_index(&self) -> Result<u64>
The last committed leaf index for Confidential accounts curve tree.
This is used to do batched inserts into the tree.
Sourcepub async fn account_inner_nodes(
&self,
key_0: NodeLocation,
) -> Result<Option<CompressedInner>>
pub async fn account_inner_nodes( &self, key_0: NodeLocation, ) -> Result<Option<CompressedInner>>
Inner node storage for Confidential accounts curve tree.
Sourcepub async fn account_curve_tree_current_root(
&self,
) -> Result<Option<TimestampedTreeRoot<CompressedCurveTreeRoot>>>
pub async fn account_curve_tree_current_root( &self, ) -> Result<Option<TimestampedTreeRoot<CompressedCurveTreeRoot>>>
The current CurveTree Root for Confidential accounts curve tree.
Sourcepub async fn account_curve_tree_height(&self) -> Result<u8>
pub async fn account_curve_tree_height(&self) -> Result<u8>
The height of the accounts curve tree.
Sourcepub async fn account_curve_tree_roots(
&self,
key_0: u32,
) -> Result<Option<TimestampedTreeRoot<CompressedCurveTreeRoot>>>
pub async fn account_curve_tree_roots( &self, key_0: u32, ) -> Result<Option<TimestampedTreeRoot<CompressedCurveTreeRoot>>>
CurveTree Roots for Confidential accounts curve tree.
At the end of each block we will store the root of the accounts curve tree. The map key is the block number and the value is the root of the accounts curve tree.
Sourcepub async fn account_curve_tree_last_update(&self) -> Result<CurveTreeTimestamp>
pub async fn account_curve_tree_last_update(&self) -> Result<CurveTreeTimestamp>
The block number of the last account curve tree root update.
This is used to track the last time the account curve tree was updated.
Sourcepub async fn account_curve_tree_last_pruned(&self) -> Result<u32>
pub async fn account_curve_tree_last_pruned(&self) -> Result<u32>
The block number of the last account curve tree root pruned.
For keeping track of the current pruning point of the account curve tree roots.
Sourcepub async fn account_state_commitment_nullifiers(
&self,
key_0: AccountStateNullifier,
) -> Result<Option<()>>
pub async fn account_state_commitment_nullifiers( &self, key_0: AccountStateNullifier, ) -> Result<Option<()>>
Nullifiers for Confidential account state commitments.
This is used to ensure that the same account state commitment cannot be used twice.
Sourcepub async fn fee_account_registrations(
&self,
key_0: AccountPublicKey,
) -> Result<bool>
pub async fn fee_account_registrations( &self, key_0: AccountPublicKey, ) -> Result<bool>
Confidential fee account egistrations.
The chain must prevent the same account from registering the multiple times.
Sourcepub async fn fee_account_leaves(
&self,
key_0: u64,
) -> Result<Option<FeeAccountStateCommitment>>
pub async fn fee_account_leaves( &self, key_0: u64, ) -> Result<Option<FeeAccountStateCommitment>>
Leaf storage for Confidential fee accounts curve tree.
The leaves are immutable, so we use a simple storage map.
Sourcepub async fn next_fee_account_leaf_index(&self) -> Result<u64>
pub async fn next_fee_account_leaf_index(&self) -> Result<u64>
Next leaf index for Confidential fee accounts curve tree.
This is used to allocate new leaves in the tree.
Sourcepub async fn last_committed_fee_account_leaf_index(&self) -> Result<u64>
pub async fn last_committed_fee_account_leaf_index(&self) -> Result<u64>
The last committed leaf index for Confidential fee accounts curve tree.
This is used to do batched inserts into the tree.
Sourcepub async fn fee_account_inner_nodes(
&self,
key_0: NodeLocation,
) -> Result<Option<CompressedInner>>
pub async fn fee_account_inner_nodes( &self, key_0: NodeLocation, ) -> Result<Option<CompressedInner>>
Inner node storage for Confidential fee accounts curve tree.
Sourcepub async fn fee_account_curve_tree_current_root(
&self,
) -> Result<Option<TimestampedTreeRoot<CompressedCurveTreeRoot>>>
pub async fn fee_account_curve_tree_current_root( &self, ) -> Result<Option<TimestampedTreeRoot<CompressedCurveTreeRoot>>>
The current CurveTree Root for Confidential fee accounts curve tree.
Sourcepub async fn fee_account_curve_tree_height(&self) -> Result<u8>
pub async fn fee_account_curve_tree_height(&self) -> Result<u8>
The height of the fee accounts curve tree.
Sourcepub async fn fee_account_curve_tree_roots(
&self,
key_0: u32,
) -> Result<Option<TimestampedTreeRoot<CompressedCurveTreeRoot>>>
pub async fn fee_account_curve_tree_roots( &self, key_0: u32, ) -> Result<Option<TimestampedTreeRoot<CompressedCurveTreeRoot>>>
CurveTree Roots for Confidential fee accounts curve tree.
At the end of each block we will store the root of the fee accounts curve tree. The map key is the block number and the value is the root of the fee accounts curve tree.
Sourcepub async fn fee_account_curve_tree_last_update(
&self,
) -> Result<CurveTreeTimestamp>
pub async fn fee_account_curve_tree_last_update( &self, ) -> Result<CurveTreeTimestamp>
The block number of the last fee account curve tree root update.
This is used to track the last time the fee account curve tree was updated.
Sourcepub async fn fee_account_curve_tree_last_pruned(&self) -> Result<u32>
pub async fn fee_account_curve_tree_last_pruned(&self) -> Result<u32>
The block number of the last fee account curve tree root pruned.
For keeping track of the current pruning point of the fee account curve tree roots.
Sourcepub async fn fee_account_state_commitment_nullifiers(
&self,
key_0: FeeAccountStateNullifier,
) -> Result<Option<()>>
pub async fn fee_account_state_commitment_nullifiers( &self, key_0: FeeAccountStateNullifier, ) -> Result<Option<()>>
Nullifiers for Confidential fee account state commitments.
This is used to ensure that the same fee account state commitment cannot be used twice.
Sourcepub async fn settlement_state(
&self,
key_0: SettlementRef,
) -> Result<Option<SettlementStatus>>
pub async fn settlement_state( &self, key_0: SettlementRef, ) -> Result<Option<SettlementStatus>>
The settlement status.
Sourcepub async fn settlement_memo(
&self,
key_0: SettlementRef,
) -> Result<Option<Vec<u8>>>
pub async fn settlement_memo( &self, key_0: SettlementRef, ) -> Result<Option<Vec<u8>>>
The settlement memo.
Sourcepub async fn settlement_legs(
&self,
key_0: SettlementRef,
key_1: u8,
) -> Result<Option<LegEncrypted>>
pub async fn settlement_legs( &self, key_0: SettlementRef, key_1: u8, ) -> Result<Option<LegEncrypted>>
The settlement legs.
This is a double map where the first key is the settlement ID and the second key is the leg ID. The value is the DartSettlementLeg.
Sourcepub async fn settlement_leg_count(
&self,
key_0: SettlementRef,
) -> Result<Option<u32>>
pub async fn settlement_leg_count( &self, key_0: SettlementRef, ) -> Result<Option<u32>>
The number of legs in each settlement.
Sourcepub async fn settlement_pending_affirmations(
&self,
key_0: SettlementRef,
) -> Result<u32>
pub async fn settlement_pending_affirmations( &self, key_0: SettlementRef, ) -> Result<u32>
The number of pending affirmations for a settlement. This is used to track when a settlement can be executed.
Sourcepub async fn settlement_pending_finalizations(
&self,
key_0: SettlementRef,
) -> Result<u32>
pub async fn settlement_pending_finalizations( &self, key_0: SettlementRef, ) -> Result<u32>
The number of pending finalizations for a settlement. This is used to track when a settlement can be finalized and all storage can be cleaned up.
Sourcepub async fn leg_affirmation_status(
&self,
key_0: SettlementRef,
key_1: u8,
key_2: LegAffirmParty,
) -> Result<Option<AffirmationStatus>>
pub async fn leg_affirmation_status( &self, key_0: SettlementRef, key_1: u8, key_2: LegAffirmParty, ) -> Result<Option<AffirmationStatus>>
The affirmation status of each party in a settlement leg. This is a triple map where the first key is the settlement ID, the second key is the leg ID, and the third key is the party (sender, receiver, mediator).
Sourcepub async fn current_worker_session_id(&self) -> Result<Option<u32>>
pub async fn current_worker_session_id(&self) -> Result<Option<u32>>
The WorkerSessionId for the current block.