MultiBlockMigrationsCallApi

Struct MultiBlockMigrationsCallApi 

pub struct MultiBlockMigrationsCallApi<'api> { /* private fields */ }

Implementations

Source

impl<'api> MultiBlockMigrationsCallApi<'api>

pub fn force_set_cursor( &self, cursor: Option<MigrationCursor<Vec<u8>, u32>>, ) -> Result<WrappedCall>

Allows root to set a cursor to forcefully start, stop or forward the migration process.

Should normally not be needed and is only in place as emergency measure. Note that restarting the migration process in this manner will not call the [MigrationStatusHandler::started] hook or emit an UpgradeStarted event.

pub fn force_set_active_cursor( &self, index: u32, inner_cursor: Option<Vec<u8>>, started_at: Option<u32>, ) -> Result<WrappedCall>

Allows root to set an active cursor to forcefully start/forward the migration process.

This is an edge-case version of Self::force_set_cursor that allows to set the started_at value to the next block number. Otherwise this would not be possible, since force_set_cursor takes an absolute block number. Setting started_at to None indicates that the current block number plus one should be used.

pub fn force_onboard_mbms(&self) -> Result<WrappedCall>

Forces the onboarding of the migrations.

This process happens automatically on a runtime upgrade. It is in place as an emergency measurement. The cursor needs to be None for this to succeed.

pub fn clear_historic( &self, selector: HistoricCleanupSelector<Vec<u8>>, ) -> Result<WrappedCall>

Clears the Historic set.

map_cursor must be set to the last value that was returned by the HistoricCleared event. The first time None can be used. limit must be chosen in a way that will result in a sensible weight.