RelayerPagedQueryApi

Struct RelayerPagedQueryApi 

pub struct RelayerPagedQueryApi<'api> { /* private fields */ }

Implementations

Source

impl<'api> RelayerPagedQueryApi<'api>

pub fn subsidies(&self) -> StoragePaged<AccountId, Subsidy<AccountId>>

The subsidy for a user_key if they are being subsidised, as a map user_key => Subsidy.

A key can only have one subsidy at a time. Accepting a new subsidy will replace any existing subsidy.

pub fn pending_subsidies( &self, key_0: AccountId, ) -> StoragePaged<AccountId, u128>

Pending subsidies for a user_key from a paying_key.

This is used to track subsidies that have been authorised but not yet accepted.

The paying key can update or cancel the subsidy before it is accepted.

pub fn relay_tx_nonces(&self) -> StoragePaged<AccountId, u64>

Nonce for relay_tx.