pub struct RelayerQueryApi<'api> { /* private fields */ }Implementations
Sourceimpl<'api> RelayerQueryApi<'api>
impl<'api> RelayerQueryApi<'api>
Sourcepub async fn subsidies(
&self,
key_0: AccountId,
) -> Result<Option<Subsidy<AccountId>>>
pub async fn subsidies( &self, key_0: AccountId, ) -> Result<Option<Subsidy<AccountId>>>
The subsidy for a user_key if they are being subsidised,
as a map user_key => Subsidy.
A key can only have one subsidy at a time. Accepting a new subsidy will replace any existing subsidy.
Sourcepub async fn pending_subsidies(
&self,
key_0: AccountId,
key_1: AccountId,
) -> Result<Option<u128>>
pub async fn pending_subsidies( &self, key_0: AccountId, key_1: AccountId, ) -> Result<Option<u128>>
Pending subsidies for a user_key from a paying_key.
This is used to track subsidies that have been authorised but not yet accepted.
The paying key can update or cancel the subsidy before it is accepted.
Sourcepub async fn relay_tx_nonces(&self, key_0: AccountId) -> Result<u64>
pub async fn relay_tx_nonces(&self, key_0: AccountId) -> Result<u64>
Nonce for relay_tx.