pub struct RevivePagedQueryApi<'api> { /* private fields */ }Implementations
Sourceimpl<'api> RevivePagedQueryApi<'api>
impl<'api> RevivePagedQueryApi<'api>
Sourcepub fn pristine_code(&self) -> StoragePaged<H256, Vec<u8>>
pub fn pristine_code(&self) -> StoragePaged<H256, Vec<u8>>
A mapping from a contract’s code hash to its code.
The code’s size is bounded by [crate::limits::BLOB_BYTES] for PVM and
[revm::primitives::eip170::MAX_CODE_SIZE] for EVM bytecode.
Sourcepub fn code_info_of(&self) -> StoragePaged<H256, CodeInfo>
pub fn code_info_of(&self) -> StoragePaged<H256, CodeInfo>
A mapping from a contract’s code hash to its code info.
Sourcepub fn account_info_of(&self) -> StoragePaged<H160, AccountInfo>
pub fn account_info_of(&self) -> StoragePaged<H160, AccountInfo>
The data associated to a contract or externally owned account.
Sourcepub fn immutable_data_of(&self) -> StoragePaged<H160, Vec<u8>>
pub fn immutable_data_of(&self) -> StoragePaged<H160, Vec<u8>>
The immutable data associated with a given account.
Sourcepub fn deletion_queue(&self) -> StoragePaged<u32, Vec<u8>>
pub fn deletion_queue(&self) -> StoragePaged<u32, Vec<u8>>
Evicted contracts that await child trie deletion.
Child trie deletion is a heavy operation depending on the amount of storage items
stored in said trie. Therefore this operation is performed lazily in on_idle.
Sourcepub fn original_account(&self) -> StoragePaged<H160, AccountId>
pub fn original_account(&self) -> StoragePaged<H160, AccountId>
Map a Ethereum address to its original AccountId32.
When deriving a H160 from an AccountId32 we use a hash function. In order to
reconstruct the original account we need to store the reverse mapping here.
Register your AccountId32 using [Pallet::map_account] in order to
use it with this pallet.
Sourcepub fn block_hash(&self) -> StoragePaged<u32, H256>
pub fn block_hash(&self) -> StoragePaged<u32, H256>
Mapping for block number and hashes.
The maximum number of elements stored is capped by the block hash count BLOCK_HASH_COUNT.