SystemCallApi

Struct SystemCallApi 

pub struct SystemCallApi<'api> { /* private fields */ }

Implementations

Source

impl<'api> SystemCallApi<'api>

pub fn remark(&self, remark: Vec<u8>) -> Result<WrappedCall>

Make some on-chain remark.

Can be executed by every origin.

pub fn set_heap_pages(&self, pages: u64) -> Result<WrappedCall>

Set the number of pages in the WebAssembly environment’s heap.

pub fn set_code(&self, code: Vec<u8>) -> Result<WrappedCall>

Set the new runtime code.

pub fn set_code_without_checks(&self, code: Vec<u8>) -> Result<WrappedCall>

Set the new runtime code without doing any checks of the given code.

Note that runtime upgrades will not run if this is called with a not-increasing spec version!

pub fn set_storage(&self, items: Vec<(Vec<u8>, Vec<u8>)>) -> Result<WrappedCall>

Set some items of storage.

pub fn kill_storage(&self, keys: Vec<Vec<u8>>) -> Result<WrappedCall>

Kill some items from storage.

pub fn kill_prefix(&self, prefix: Vec<u8>, subkeys: u32) -> Result<WrappedCall>

Kill all storage items with a key that starts with the given prefix.

NOTE: We rely on the Root origin to provide us the number of subkeys under the prefix we are removing to accurately calculate the weight of this function.

pub fn remark_with_event(&self, remark: Vec<u8>) -> Result<WrappedCall>

Make some on-chain remark and emit event.

pub fn authorize_upgrade(&self, code_hash: H256) -> Result<WrappedCall>

Authorize an upgrade to a given code_hash for the runtime. The runtime can be supplied later.

This call requires Root origin.

pub fn authorize_upgrade_without_checks( &self, code_hash: H256, ) -> Result<WrappedCall>

Authorize an upgrade to a given code_hash for the runtime. The runtime can be supplied later.

WARNING: This authorizes an upgrade that will take place without any safety checks, for example that the spec name remains the same and that the version number increases. Not recommended for normal use. Use authorize_upgrade instead.

This call requires Root origin.

pub fn apply_authorized_upgrade(&self, code: Vec<u8>) -> Result<WrappedCall>

Provide the preimage (runtime binary) code for an upgrade that has been authorized.

If the authorization required a version check, this call will ensure the spec name remains unchanged and that the spec version has increased.

Depending on the runtime’s OnSetCode configuration, this function may directly apply the new code in the same block or attempt to schedule the upgrade.

All origins are allowed.