Struct polymesh_api::polymesh::api::test_utils::TestUtilsCallApi
source · pub struct TestUtilsCallApi<'api> { /* private fields */ }Implementations
sourceimpl<'api> TestUtilsCallApi<'api>
impl<'api> TestUtilsCallApi<'api>
sourcepub fn register_did(
&self,
secondary_keys: Vec<SecondaryKey<AccountId>>
) -> Result<WrappedCall>
pub fn register_did( &self, secondary_keys: Vec<SecondaryKey<AccountId>> ) -> Result<WrappedCall>
Generates a new IdentityID for the caller, and issues a self-generated CDD claim.
The caller account will be the primary key of that identity.
For each account of secondary_keys, a new JoinIdentity authorization is created, so
each of them will need to accept it before become part of this new IdentityID.
Errors
AlreadyLinkedif the caller account or if any of the givensecondary_keyshas already linked to anIdentityIDSecondaryKeysContainPrimaryKeyifsecondary_keyscontains the caller account.DidAlreadyExistsif auto-generated DID already exists.
sourcepub fn mock_cdd_register_did(
&self,
target_account: AccountId
) -> Result<WrappedCall>
pub fn mock_cdd_register_did( &self, target_account: AccountId ) -> Result<WrappedCall>
Registers a new Identity for the target_account and issues a CDD claim to it.
Failure
originhas to be an active CDD provider. Inactive CDD providers cannot add new claims.target_account(primary key of the new Identity) can be linked to just one and only one identity.
sourcepub fn get_my_did(&self) -> Result<WrappedCall>
pub fn get_my_did(&self) -> Result<WrappedCall>
Emits an event with caller’s identity.
sourcepub fn get_cdd_of(&self, of: AccountId) -> Result<WrappedCall>
pub fn get_cdd_of(&self, of: AccountId) -> Result<WrappedCall>
Emits an event with caller’s identity and CDD status.