pub struct ValidatorsCallApi<'api> { /* private fields */ }Implementations
Sourceimpl<'api> ValidatorsCallApi<'api>
impl<'api> ValidatorsCallApi<'api>
Sourcepub fn add_permissioned_validator(
&self,
identity: IdentityId,
intended_count: Option<u32>,
) -> Result<WrappedCall>
pub fn add_permissioned_validator( &self, identity: IdentityId, intended_count: Option<u32>, ) -> Result<WrappedCall>
Adds a permissioned identity and sets its preferences.
The dispatch origin must be Root.
Sourcepub fn remove_permissioned_validator(
&self,
identity: IdentityId,
) -> Result<WrappedCall>
pub fn remove_permissioned_validator( &self, identity: IdentityId, ) -> Result<WrappedCall>
Remove an identity from the pool of (wannabe) validator identities. Effects are known in the next session.
The dispatch origin must be Root.
Arguments
- origin Required origin for removing a potential validator.
- identity Validator’s IdentityId.
pub fn payout_stakers_by_system( &self, validator_stash: AccountId, era: u32, ) -> Result<WrappedCall>
Sourcepub fn change_slashing_allowed_for(
&self,
slashing_switch: SlashingSwitch,
) -> Result<WrappedCall>
pub fn change_slashing_allowed_for( &self, slashing_switch: SlashingSwitch, ) -> Result<WrappedCall>
Switch slashing status on the basis of given slashing_switch. Can only be called by root.
Sourcepub fn update_permissioned_validator_intended_count(
&self,
identity: IdentityId,
new_intended_count: u32,
) -> Result<WrappedCall>
pub fn update_permissioned_validator_intended_count( &self, identity: IdentityId, new_intended_count: u32, ) -> Result<WrappedCall>
Sets the intended count to new_intended_count for the given identity.
Sourcepub fn chill_from_governance(
&self,
identity: IdentityId,
stash_keys: Vec<AccountId>,
) -> Result<WrappedCall>
pub fn chill_from_governance( &self, identity: IdentityId, stash_keys: Vec<AccountId>, ) -> Result<WrappedCall>
Governance council forcefully chills a validator. Effects will be felt at the beginning of the next era.
Sourcepub fn set_commission_cap(&self, new_cap: Perbill) -> Result<WrappedCall>
pub fn set_commission_cap(&self, new_cap: Perbill) -> Result<WrappedCall>
Changes commission rate which applies to all validators. Only Governance committee is allowed to change this value.
Arguments
new_capthe new commission cap.