pub struct ReviveQueryApi<'api> { /* private fields */ }Implementations
Sourceimpl<'api> ReviveQueryApi<'api>
impl<'api> ReviveQueryApi<'api>
Sourcepub async fn pristine_code(&self, key_0: H256) -> Result<Option<Vec<u8>>>
pub async fn pristine_code(&self, key_0: H256) -> Result<Option<Vec<u8>>>
A mapping from a contract’s code hash to its code.
The code’s size is bounded by [crate::limits::BLOB_BYTES] for PVM and
[revm::primitives::eip170::MAX_CODE_SIZE] for EVM bytecode.
Sourcepub async fn code_info_of(&self, key_0: H256) -> Result<Option<CodeInfo>>
pub async fn code_info_of(&self, key_0: H256) -> Result<Option<CodeInfo>>
A mapping from a contract’s code hash to its code info.
Sourcepub async fn account_info_of(&self, key_0: H160) -> Result<Option<AccountInfo>>
pub async fn account_info_of(&self, key_0: H160) -> Result<Option<AccountInfo>>
The data associated to a contract or externally owned account.
Sourcepub async fn immutable_data_of(&self, key_0: H160) -> Result<Option<Vec<u8>>>
pub async fn immutable_data_of(&self, key_0: H160) -> Result<Option<Vec<u8>>>
The immutable data associated with a given account.
Sourcepub async fn deletion_queue(&self, key_0: u32) -> Result<Option<Vec<u8>>>
pub async fn deletion_queue(&self, key_0: u32) -> Result<Option<Vec<u8>>>
Evicted contracts that await child trie deletion.
Child trie deletion is a heavy operation depending on the amount of storage items
stored in said trie. Therefore this operation is performed lazily in on_idle.
Sourcepub async fn deletion_queue_counter(&self) -> Result<DeletionQueueManager>
pub async fn deletion_queue_counter(&self) -> Result<DeletionQueueManager>
A pair of monotonic counters used to track the latest contract marked for deletion and the latest deleted contract in queue.
Sourcepub async fn original_account(&self, key_0: H160) -> Result<Option<AccountId>>
pub async fn original_account(&self, key_0: H160) -> Result<Option<AccountId>>
Map a Ethereum address to its original AccountId32.
When deriving a H160 from an AccountId32 we use a hash function. In order to
reconstruct the original account we need to store the reverse mapping here.
Register your AccountId32 using [Pallet::map_account] in order to
use it with this pallet.
Sourcepub async fn ethereum_block(&self) -> Result<Block>
pub async fn ethereum_block(&self) -> Result<Block>
The current Ethereum block that is stored in the on_finalize method.
Note
This could be further optimized into the future to store only the minimum information needed to reconstruct the Ethereum block at the RPC level.
Since the block is convenient to have around, and the extra details are capped by a few hashes and the vector of transaction hashes, we store the block here.
Sourcepub async fn block_hash(&self, key_0: u32) -> Result<H256>
pub async fn block_hash(&self, key_0: u32) -> Result<H256>
Mapping for block number and hashes.
The maximum number of elements stored is capped by the block hash count BLOCK_HASH_COUNT.
Sourcepub async fn receipt_info_data(&self) -> Result<Vec<ReceiptGasInfo>>
pub async fn receipt_info_data(&self) -> Result<Vec<ReceiptGasInfo>>
The details needed to reconstruct the receipt info offchain.
This contains valuable information about the gas used by the transaction.
NOTE: The item is unbound and should therefore never be read on chain. It could otherwise inflate the PoV size of a block.
Sourcepub async fn eth_block_builder_ir(&self) -> Result<EthereumBlockBuilderIR>
pub async fn eth_block_builder_ir(&self) -> Result<EthereumBlockBuilderIR>
Incremental ethereum block builder.
Sourcepub async fn eth_block_builder_first_values(
&self,
) -> Result<Option<(Vec<u8>, Vec<u8>)>>
pub async fn eth_block_builder_first_values( &self, ) -> Result<Option<(Vec<u8>, Vec<u8>)>>
The first transaction and receipt of the ethereum block.
These values are moved out of the EthBlockBuilderIR to avoid serializing and
deserializing them on every transaction. Instead, they are loaded when needed.
Sourcepub async fn debug_settings_of(&self) -> Result<DebugSettings>
pub async fn debug_settings_of(&self) -> Result<DebugSettings>
Debugging settings that can be configured when DebugEnabled config is true.