pub struct SchedulerCallApi<'api> { /* private fields */ }Implementations
Sourceimpl<'api> SchedulerCallApi<'api>
impl<'api> SchedulerCallApi<'api>
Sourcepub fn schedule(
&self,
when: u32,
maybe_periodic: Option<(u32, u32)>,
priority: u8,
call: RuntimeCall,
) -> Result<WrappedCall>
pub fn schedule( &self, when: u32, maybe_periodic: Option<(u32, u32)>, priority: u8, call: RuntimeCall, ) -> Result<WrappedCall>
Anonymously schedule a task.
Sourcepub fn cancel(&self, when: u32, index: u32) -> Result<WrappedCall>
pub fn cancel(&self, when: u32, index: u32) -> Result<WrappedCall>
Cancel a scheduled task (named or anonymous), by providing the block it is scheduled for execution in, as well as the index of the task in that block’s agenda.
In the case of a named task, it will remove it from the lookup table as well.
Sourcepub fn schedule_named(
&self,
id: [u8; 32],
when: u32,
maybe_periodic: Option<(u32, u32)>,
priority: u8,
call: RuntimeCall,
) -> Result<WrappedCall>
pub fn schedule_named( &self, id: [u8; 32], when: u32, maybe_periodic: Option<(u32, u32)>, priority: u8, call: RuntimeCall, ) -> Result<WrappedCall>
Schedule a named task.
Sourcepub fn cancel_named(&self, id: [u8; 32]) -> Result<WrappedCall>
pub fn cancel_named(&self, id: [u8; 32]) -> Result<WrappedCall>
Cancel a named scheduled task.
Sourcepub fn schedule_after(
&self,
after: u32,
maybe_periodic: Option<(u32, u32)>,
priority: u8,
call: RuntimeCall,
) -> Result<WrappedCall>
pub fn schedule_after( &self, after: u32, maybe_periodic: Option<(u32, u32)>, priority: u8, call: RuntimeCall, ) -> Result<WrappedCall>
Anonymously schedule a task after a delay.
Sourcepub fn schedule_named_after(
&self,
id: [u8; 32],
after: u32,
maybe_periodic: Option<(u32, u32)>,
priority: u8,
call: RuntimeCall,
) -> Result<WrappedCall>
pub fn schedule_named_after( &self, id: [u8; 32], after: u32, maybe_periodic: Option<(u32, u32)>, priority: u8, call: RuntimeCall, ) -> Result<WrappedCall>
Schedule a named task after a delay.
Sourcepub fn set_retry(
&self,
task: (u32, u32),
retries: u8,
period: u32,
) -> Result<WrappedCall>
pub fn set_retry( &self, task: (u32, u32), retries: u8, period: u32, ) -> Result<WrappedCall>
Set a retry configuration for a task so that, in case its scheduled run fails, it will
be retried after period blocks, for a total amount of retries retries or until it
succeeds.
Tasks which need to be scheduled for a retry are still subject to weight metering and agenda space, same as a regular task. If a periodic task fails, it will be scheduled normally while the task is retrying.
Tasks scheduled as a result of a retry for a periodic task are unnamed, non-periodic
clones of the original task. Their retry configuration will be derived from the
original task’s configuration, but will have a lower value for remaining than the
original total_retries.
This call cannot be used to set a retry configuration for a named task.
Sourcepub fn set_retry_named(
&self,
id: [u8; 32],
retries: u8,
period: u32,
) -> Result<WrappedCall>
pub fn set_retry_named( &self, id: [u8; 32], retries: u8, period: u32, ) -> Result<WrappedCall>
Set a retry configuration for a named task so that, in case its scheduled run fails, it
will be retried after period blocks, for a total amount of retries retries or until
it succeeds.
Tasks which need to be scheduled for a retry are still subject to weight metering and agenda space, same as a regular task. If a periodic task fails, it will be scheduled normally while the task is retrying.
Tasks scheduled as a result of a retry for a periodic task are unnamed, non-periodic
clones of the original task. Their retry configuration will be derived from the
original task’s configuration, but will have a lower value for remaining than the
original total_retries.
This is the only way to set a retry configuration for a named task.
Sourcepub fn cancel_retry(&self, task: (u32, u32)) -> Result<WrappedCall>
pub fn cancel_retry(&self, task: (u32, u32)) -> Result<WrappedCall>
Removes the retry configuration of a task.
Sourcepub fn cancel_retry_named(&self, id: [u8; 32]) -> Result<WrappedCall>
pub fn cancel_retry_named(&self, id: [u8; 32]) -> Result<WrappedCall>
Cancel the retry configuration of a named task.